spoon.Serial

Package spoon :: Class Serial |
[hide private]
[frames] | no frames]

# Class Serial

source code

    object --+
             |
            Serial

Known Subclasses:
  transports.SpoonRPCHello

Nested Classes | [hide private]
`` | __metaclass__

Instance Methods | [hide private]
`` | decode_lazy(self) Decode all of the attributes marked as lazy that have not yet been decoded.
`` | post_deserialize(self) Called after an object is received over the network, instead of the normal `__init__` method.
`` | pre_serialize(self) Called right before this object's attributes are encoded into a stream for network travel.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Static Methods | [hide private]
`` | __new__(cls, *args, **kwargs)

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __new__(cls, *args, **kwargs) Static Method |
    Returns:
        a new object with type S, a subtype of T
Overrides: object.__new__ (inherited documentation)

### decode_lazy(self) | source code
Decode all of the attributes marked as lazy that have not yet been decoded. Returns: Number of attributes decoded. Warning: Some sort of instance level locking should be done

### post_deserialize(self) | source code
Called after an object is received over the network, instead of the normal `__init__` method.

### pre_serialize(self) | source code
Called right before this object's attributes are encoded into a stream for network travel.